"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.storeAdd = storeAdd;
const error_1 = require("@pnpm/error");
const logger_1 = require("@pnpm/logger");
const parse_wanted_dependency_1 = require("@pnpm/parse-wanted-dependency");
const pick_registry_for_package_1 = require("@pnpm/pick-registry-for-package");
async function storeAdd(fuzzyDeps, opts) {
    const reporter = opts?.reporter;
    if ((reporter != null) && typeof reporter === 'function') {
        logger_1.streamParser.on('data', reporter);
    }
    const deps = fuzzyDeps.map((dep) => (0, parse_wanted_dependency_1.parseWantedDependency)(dep));
    let hasFailures = false;
    const prefix = opts.prefix ?? process.cwd();
    const registries = opts.registries ?? {
        default: 'https://registry.npmjs.org/',
    };
    await Promise.all(deps.map(async (dep) => {
        try {
            const pkgResponse = await opts.storeController.requestPackage(dep, {
                downloadPriority: 1,
                lockfileDir: prefix,
                preferredVersions: {},
                projectDir: prefix,
                registry: (dep.alias && (0, pick_registry_for_package_1.pickRegistryForPackage)(registries, dep.alias)) ?? registries.default,
                supportedArchitectures: opts.supportedArchitectures,
            });
            await pkgResponse.fetching();
            (0, logger_1.globalInfo)(`+ ${pkgResponse.body.id}`);
        }
        catch (e) { // eslint-disable-line
            hasFailures = true;
            (0, logger_1.logger)('store').error(e);
        }
    }));
    if ((reporter != null) && typeof reporter === 'function') {
        logger_1.streamParser.removeListener('data', reporter);
    }
    if (hasFailures) {
        throw new error_1.PnpmError('STORE_ADD_FAILURE', 'Some packages have not been added correctly');
    }
}
//# sourceMappingURL=storeAdd.js.map